@@ -13,7 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-from google.cloud.deploy import gapic_version as package_version
+from google.cloud.deploy_v1 import gapic_version as package_version
 
 __version__ = package_version.__version__
 
@@ -22,17 +22,31 @@ from .services.cloud_deploy import CloudDeployAsyncClient, CloudDeployClient
 from .types.cloud_deploy import (
     AbandonReleaseRequest,
     AbandonReleaseResponse,
+    AdvanceChildRolloutJob,
+    AdvanceChildRolloutJobRun,
+    AdvanceRolloutRequest,
+    AdvanceRolloutResponse,
     AnthosCluster,
     ApproveRolloutRequest,
     ApproveRolloutResponse,
     BuildArtifact,
+    Canary,
+    CanaryDeployment,
+    CancelRolloutRequest,
+    CancelRolloutResponse,
+    ChildRolloutJobs,
+    CloudRunConfig,
     CloudRunLocation,
     CloudRunMetadata,
+    CloudRunRenderMetadata,
     Config,
+    CreateChildRolloutJob,
+    CreateChildRolloutJobRun,
     CreateDeliveryPipelineRequest,
     CreateReleaseRequest,
     CreateRolloutRequest,
     CreateTargetRequest,
+    CustomCanaryDeployment,
     DefaultPool,
     DeleteDeliveryPipelineRequest,
     DeleteTargetRequest,
@@ -49,8 +63,11 @@ from .types.cloud_deploy import (
     GetRolloutRequest,
     GetTargetRequest,
     GkeCluster,
+    IgnoreJobRequest,
+    IgnoreJobResponse,
     Job,
     JobRun,
+    KubernetesConfig,
     ListDeliveryPipelinesRequest,
     ListDeliveryPipelinesResponse,
     ListJobRunsRequest,
@@ -62,16 +79,20 @@ from .types.cloud_deploy import (
     ListTargetsRequest,
     ListTargetsResponse,
     Metadata,
+    MultiTarget,
     OperationMetadata,
     Phase,
     PipelineCondition,
     PipelineReadyCondition,
     PrivatePool,
     Release,
+    RenderMetadata,
     RetryJobRequest,
     RetryJobResponse,
     Rollout,
+    RuntimeConfig,
     SerialPipeline,
+    SkaffoldSupportState,
     SkaffoldVersion,
     Stage,
     Standard,
@@ -79,6 +100,9 @@ from .types.cloud_deploy import (
     Target,
     TargetArtifact,
     TargetsPresentCondition,
+    TargetsTypeCondition,
+    TerminateJobRunRequest,
+    TerminateJobRunResponse,
     UpdateDeliveryPipelineRequest,
     UpdateTargetRequest,
     VerifyJob,
@@ -98,18 +122,32 @@ __all__ = (
     "CloudDeployAsyncClient",
     "AbandonReleaseRequest",
     "AbandonReleaseResponse",
+    "AdvanceChildRolloutJob",
+    "AdvanceChildRolloutJobRun",
+    "AdvanceRolloutRequest",
+    "AdvanceRolloutResponse",
     "AnthosCluster",
     "ApproveRolloutRequest",
     "ApproveRolloutResponse",
     "BuildArtifact",
+    "Canary",
+    "CanaryDeployment",
+    "CancelRolloutRequest",
+    "CancelRolloutResponse",
+    "ChildRolloutJobs",
     "CloudDeployClient",
+    "CloudRunConfig",
     "CloudRunLocation",
     "CloudRunMetadata",
+    "CloudRunRenderMetadata",
     "Config",
+    "CreateChildRolloutJob",
+    "CreateChildRolloutJobRun",
     "CreateDeliveryPipelineRequest",
     "CreateReleaseRequest",
     "CreateRolloutRequest",
     "CreateTargetRequest",
+    "CustomCanaryDeployment",
     "DefaultPool",
     "DeleteDeliveryPipelineRequest",
     "DeleteTargetRequest",
@@ -127,9 +165,12 @@ __all__ = (
     "GetRolloutRequest",
     "GetTargetRequest",
     "GkeCluster",
+    "IgnoreJobRequest",
+    "IgnoreJobResponse",
     "Job",
     "JobRun",
     "JobRunNotificationEvent",
+    "KubernetesConfig",
     "ListDeliveryPipelinesRequest",
     "ListDeliveryPipelinesResponse",
     "ListJobRunsRequest",
@@ -141,6 +182,7 @@ __all__ = (
     "ListTargetsRequest",
     "ListTargetsResponse",
     "Metadata",
+    "MultiTarget",
     "OperationMetadata",
     "Phase",
     "PipelineCondition",
@@ -149,11 +191,14 @@ __all__ = (
     "Release",
     "ReleaseNotificationEvent",
     "ReleaseRenderEvent",
+    "RenderMetadata",
     "RetryJobRequest",
     "RetryJobResponse",
     "Rollout",
     "RolloutNotificationEvent",
+    "RuntimeConfig",
     "SerialPipeline",
+    "SkaffoldSupportState",
     "SkaffoldVersion",
     "Stage",
     "Standard",
@@ -162,6 +207,9 @@ __all__ = (
     "TargetArtifact",
     "TargetNotificationEvent",
     "TargetsPresentCondition",
+    "TargetsTypeCondition",
+    "TerminateJobRunRequest",
+    "TerminateJobRunResponse",
     "Type",
     "UpdateDeliveryPipelineRequest",
     "UpdateTargetRequest",
