@@ -16,17 +16,31 @@
 from .cloud_deploy import (
     AbandonReleaseRequest,
     AbandonReleaseResponse,
+    AdvanceChildRolloutJob,
+    AdvanceChildRolloutJobRun,
+    AdvanceRolloutRequest,
+    AdvanceRolloutResponse,
     AnthosCluster,
     ApproveRolloutRequest,
     ApproveRolloutResponse,
     BuildArtifact,
+    Canary,
+    CanaryDeployment,
+    CancelRolloutRequest,
+    CancelRolloutResponse,
+    ChildRolloutJobs,
+    CloudRunConfig,
     CloudRunLocation,
     CloudRunMetadata,
+    CloudRunRenderMetadata,
     Config,
+    CreateChildRolloutJob,
+    CreateChildRolloutJobRun,
     CreateDeliveryPipelineRequest,
     CreateReleaseRequest,
     CreateRolloutRequest,
     CreateTargetRequest,
+    CustomCanaryDeployment,
     DefaultPool,
     DeleteDeliveryPipelineRequest,
     DeleteTargetRequest,
@@ -43,8 +57,11 @@ from .cloud_deploy import (
     GetRolloutRequest,
     GetTargetRequest,
     GkeCluster,
+    IgnoreJobRequest,
+    IgnoreJobResponse,
     Job,
     JobRun,
+    KubernetesConfig,
     ListDeliveryPipelinesRequest,
     ListDeliveryPipelinesResponse,
     ListJobRunsRequest,
@@ -56,16 +73,20 @@ from .cloud_deploy import (
     ListTargetsRequest,
     ListTargetsResponse,
     Metadata,
+    MultiTarget,
     OperationMetadata,
     Phase,
     PipelineCondition,
     PipelineReadyCondition,
     PrivatePool,
     Release,
+    RenderMetadata,
     RetryJobRequest,
     RetryJobResponse,
     Rollout,
+    RuntimeConfig,
     SerialPipeline,
+    SkaffoldSupportState,
     SkaffoldVersion,
     Stage,
     Standard,
@@ -73,6 +94,9 @@ from .cloud_deploy import (
     Target,
     TargetArtifact,
     TargetsPresentCondition,
+    TargetsTypeCondition,
+    TerminateJobRunRequest,
+    TerminateJobRunResponse,
     UpdateDeliveryPipelineRequest,
     UpdateTargetRequest,
     VerifyJob,
@@ -88,17 +112,31 @@ from .target_notification_payload import TargetNotificationEvent
 __all__ = (
     "AbandonReleaseRequest",
     "AbandonReleaseResponse",
+    "AdvanceChildRolloutJob",
+    "AdvanceChildRolloutJobRun",
+    "AdvanceRolloutRequest",
+    "AdvanceRolloutResponse",
     "AnthosCluster",
     "ApproveRolloutRequest",
     "ApproveRolloutResponse",
     "BuildArtifact",
+    "Canary",
+    "CanaryDeployment",
+    "CancelRolloutRequest",
+    "CancelRolloutResponse",
+    "ChildRolloutJobs",
+    "CloudRunConfig",
     "CloudRunLocation",
     "CloudRunMetadata",
+    "CloudRunRenderMetadata",
     "Config",
+    "CreateChildRolloutJob",
+    "CreateChildRolloutJobRun",
     "CreateDeliveryPipelineRequest",
     "CreateReleaseRequest",
     "CreateRolloutRequest",
     "CreateTargetRequest",
+    "CustomCanaryDeployment",
     "DefaultPool",
     "DeleteDeliveryPipelineRequest",
     "DeleteTargetRequest",
@@ -115,8 +153,11 @@ __all__ = (
     "GetRolloutRequest",
     "GetTargetRequest",
     "GkeCluster",
+    "IgnoreJobRequest",
+    "IgnoreJobResponse",
     "Job",
     "JobRun",
+    "KubernetesConfig",
     "ListDeliveryPipelinesRequest",
     "ListDeliveryPipelinesResponse",
     "ListJobRunsRequest",
@@ -128,15 +169,18 @@ __all__ = (
     "ListTargetsRequest",
     "ListTargetsResponse",
     "Metadata",
+    "MultiTarget",
     "OperationMetadata",
     "Phase",
     "PipelineCondition",
     "PipelineReadyCondition",
     "PrivatePool",
     "Release",
+    "RenderMetadata",
     "RetryJobRequest",
     "RetryJobResponse",
     "Rollout",
+    "RuntimeConfig",
     "SerialPipeline",
     "SkaffoldVersion",
     "Stage",
@@ -145,10 +189,14 @@ __all__ = (
     "Target",
     "TargetArtifact",
     "TargetsPresentCondition",
+    "TargetsTypeCondition",
+    "TerminateJobRunRequest",
+    "TerminateJobRunResponse",
     "UpdateDeliveryPipelineRequest",
     "UpdateTargetRequest",
     "VerifyJob",
     "VerifyJobRun",
+    "SkaffoldSupportState",
     "DeliveryPipelineNotificationEvent",
     "JobRunNotificationEvent",
     "Type",
