@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from __future__ import annotations
+
 from typing import MutableMapping, MutableSequence
 
 import proto  # type: ignore
@@ -28,6 +30,15 @@ __protobuf__ = proto.module(
 class Type(proto.Enum):
     r"""Type indicates the type of the log entry and can be used as a
     filter.
+
+    Values:
+        TYPE_UNSPECIFIED (0):
+            Type is unspecified.
+        TYPE_PUBSUB_NOTIFICATION_FAILURE (1):
+            A Pub/Sub notification failed to be sent.
+        TYPE_RENDER_STATUES_CHANGE (2):
+            Deprecated: This field is never used. Use release_render log
+            type instead.
     """
     TYPE_UNSPECIFIED = 0
     TYPE_PUBSUB_NOTIFICATION_FAILURE = 1
